@@ -17,6 +17,7 @@
 
 #include "levelloader.h"
 #include "globals.h"
+#include "kbreakout_debug.h"
 
 #include <QDomDocument>
 #include <QFile>
@@ -26,8 +27,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 
-#include <QDebug>
-
 LevelLoader::LevelLoader(QObject *parent)
     : QObject(parent)
 {
@@ -65,8 +64,8 @@ void LevelLoader::setLevelset(const QString &levelname)
 
     // Loading document model
     // Locating the path in the filesystem
-    QString path = QLatin1String("levelsets/") + m_levelname + QLatin1String(".levelset");
-    path =  QStandardPaths::locate(QStandardPaths::DataLocation, path);
+    QString path = QStringLiteral("levelsets/%1.levelset").arg(m_levelname);
+    path = QStandardPaths::locate(QStandardPaths::AppDataLocation, path);
     // --
 
     delete m_levelset;
@@ -257,8 +256,8 @@ void LevelLoader::loadOldStyleLevel()
     m_level++;
 
     // Loading the levelset
-    QString path = QLatin1String("levelsets/") + m_levelname + QLatin1String(".levelset");
-    path = QStandardPaths::locate(QStandardPaths::DataLocation, path);
+    QString path = QStringLiteral("levelsets/%1.levelset").arg(m_levelname);
+    path = QStandardPaths::locate(QStandardPaths::AppDataLocation, path);
     KConfig file(path, KConfig::SimpleConfig);
 
     QString levelName(QLatin1String("level") + QString::number(m_level));
@@ -284,7 +283,7 @@ void LevelLoader::loadOldStyleLevel()
             return;
         }
 
-        qDebug() << line << endl;
+        qCDebug(KBREAKOUT_General) << line << endl;
 
         if (line.size() > WIDTH) {
             qCritical() << "Invalid file: too many bricks\n";
